import type { RpcRequest, RpcResponse } from './rpc';
import { getPrivateKeys } from './snap/getPrivateKeys';

export type * from './rpc';

/**
 * Handle incoming JSON-RPC requests, sent through `wallet_invokeSnap`.
 * @param args - The request handler args as object.
 * @param args.origin - The origin of the request, e.g., the website that
 * invoked the snap.
 * @param args.request - A validated JSON-RPC request object.
 * @returns The result of `snap_dialog`.
 * @throws If the request method is not valid for this snap.
 */
export const onRpcRequest = async ({
  origin,
  request,
}: { origin: string; request: RpcRequest }): Promise<RpcResponse> => {
  switch (request.method) {
    case 'hive_getPrivateKeys':
      return {
        keys: await getPrivateKeys(origin, request.params.keys)
      };

    default:
      throw new Error('Method not found.');
  }
};
